@@ -39,6 +39,8 @@
  */
 #define DEFAULT_COOKIE_TIMEOUT          (1800)
 
+extern apr_proc_mutex_t *global_cookie_mutex;
+
 
 typedef struct cookie_t cookie_t;
 
@@ -49,6 +51,12 @@ struct cookie_t {
 };
 
 
+typedef struct cookie_lock_t cookie_lock_t;
+
+struct cookie_lock_t {
+  apr_file_t *file;
+};
+
 extern cookie_t* chxj_save_cookie(
   request_rec*            r);
 
@@ -72,7 +80,8 @@ extern void chxj_cookie_db_unlock(
   request_rec*            r, 
   apr_file_t*             file);
 
-extern void chxj_delete_cookie(request_rec *r, const char *cookie_id);
+#define chxj_delete_cookie(X,Y) __chxj_delete_cookie(X,Y,__FILE__,__LINE__)
+extern void __chxj_delete_cookie(request_rec *r, const char *cookie_id, const char *__filename__, int __line__);
 
 extern char* chxj_cookie_db_name_create(
   request_rec*            r, 
@@ -113,6 +122,12 @@ extern cookie_t* chxj_update_cookie(
   cookie_t*    old_cookie);
 
 extern apr_time_t chxj_parse_cookie_expires(const char *s);
+
+extern cookie_lock_t *__chxj_cookie_lock(request_rec *r, const char *filename, int line);
+extern int __chxj_cookie_unlock(request_rec *r, cookie_lock_t *lock, const char *filename, int line);
+
+#define chxj_cookie_lock(X) __chxj_cookie_lock((X),__FILE__,__LINE__)
+#define chxj_cookie_unlock(X,L) __chxj_cookie_unlock((X),(L),__FILE__,__LINE__)
 #endif
 /*
  * vim:ts=2 et
