@@ -471,7 +471,7 @@ chxj_exchange_chtml10(
   chxj_dump_out("[dst] CHTML -> CHTML1.0", dst, *dstlen);
 #endif
 
-  DBG(r, "end   chxj_exchange_chtml10() cookie_id=[%s] time=[%lld]", (cookie) ? cookie->cookie_id : "", apr_time_now() - t);
+  DBG(r, "end   chxj_exchange_chtml10() cookie_id=[%s] time=[%" APR_INT64_T_FMT  "]", (cookie) ? cookie->cookie_id : "", apr_time_now() - t);
 
   return dst;
 }
@@ -1879,8 +1879,10 @@ s_chtml10_start_form_tag(void *pdoc, Node *node)
     char *q;
     q = strchr(attr_value, '?');
     if (q) {
-      new_hidden_tag = chxj_form_action_to_hidden_tag(doc->pool, attr_value, 0, post_flag);
-      *q = 0;
+      new_hidden_tag = chxj_form_action_to_hidden_tag(r, doc->pool, attr_value, 0, post_flag);
+      if (new_hidden_tag) {
+        *q = 0;
+      }
     }
     W10_L(" action=\"");
     W10_V(attr_value);
